@@ -39,7 +39,7 @@ else: # > 3.0
     def pickle_load(f):
         return pickle.load(f,encoding="bytes")
 
-version="3.12.0"
+version="3.13.0"
 os.environ['CURRENT_VERSION_ID']=version
 
 global_cache = 'global_cache'
@@ -75,10 +75,16 @@ except ImportError:
     from fanficfare.six.moves import http_cookiejar as cl
 
 
-def write_story(config, adapter, writeformat, metaonly=False, outstream=None):
+def write_story(config, adapter, writeformat,
+                metaonly=False, nooutput=False,
+                outstream=None):
     writer = writers.getWriter(writeformat, config, adapter)
-    writer.writeStory(outstream=outstream, metaonly=metaonly)
     output_filename = writer.getOutputFileName()
+    if nooutput:
+        logger.info("Output suppressed by --no-output")
+    else:
+        writer.writeStory(outstream=outstream, metaonly=metaonly)
+        logger.debug("Successfully wrote '%s'"%output_filename)
     del writer
     return output_filename
 
@@ -117,6 +123,9 @@ def main(argv=None,
     parser.add_option('-j', '--json-meta',
                       action='store_true', dest='jsonmeta',
                       help='Output metadata as JSON with download, or with --meta-only flag.  (Only JSON will be output with --meta-only flag.)', )
+    parser.add_option('--no-output',
+                      action='store_true', dest='nooutput',
+                      help='Do not download chapters and do not write output file.  Intended for testing and with --meta-only.', )
     parser.add_option('-u', '--update-epub',
                       action='store_true', dest='update',
                       help='Update an existing epub(if present) with new chapters.  Give either epub filename or story URL.', )
@@ -365,7 +374,8 @@ def do_download(arg,
             adapter.setChaptersRange(options.begin, options.end)
 
         # check for updating from URL (vs from file)
-        if options.update and not chaptercount:
+        update_story = options.update
+        if update_story and not chaptercount:
             try:
                 writer = writers.getWriter('epub', configuration, adapter)
                 output_filename = writer.getOutputFileName()
@@ -373,7 +383,7 @@ def do_download(arg,
                 print('Updating %s, URL: %s' % (output_filename, url))
             except Exception as e:
                 print("Failed to read epub for update: (%s) Continuing with update=false"%e)
-                options.update = False
+                update_story = False
 
         # Check for include_images without no_image_processing. In absence of PIL, give warning.
         if adapter.getConfig('include_images') and not adapter.getConfig('no_image_processing'):
@@ -421,7 +431,7 @@ def do_download(arg,
                     print('Adult check required on non-interactive process. Set is_adult:true in personal.ini or pass -o "is_adult=true" to the command.')
                     return
 
-        if options.update and not options.force:
+        if update_story and not options.force:
             urlchaptercount = int(adapter.getStoryMetadataOnly().getMetadata('numChapters').replace(',',''))
             # returns int adjusted for start-end range.
             urlchaptercount = adapter.getStoryMetadataOnly().getChapterCount()
@@ -448,7 +458,7 @@ def do_download(arg,
 
                 print('Do update - epub(%d) vs url(%d)' % (chaptercount, urlchaptercount))
 
-                if not options.update and chaptercount == urlchaptercount and adapter.getConfig('do_update_hook'):
+                if not update_story and chaptercount == urlchaptercount and adapter.getConfig('do_update_hook'):
                     adapter.hookForUpdates(chaptercount)
 
                 if adapter.getConfig('pre_process_safepattern'):
@@ -457,9 +467,8 @@ def do_download(arg,
                     metadata = adapter.story.getAllMetadata()
                 call(string.Template(adapter.getConfig('pre_process_cmd')).substitute(metadata), shell=True)
 
-                output_filename = write_story(configuration, adapter, 'epub')
-                logger.debug("Successfully wrote '%s'"%output_filename)
-
+                output_filename = write_story(configuration, adapter, 'epub',
+                                              nooutput=options.nooutput)
 
         else:
             if not options.metaonly and adapter.getConfig('pre_process_cmd'):
@@ -469,8 +478,8 @@ def do_download(arg,
                     metadata = adapter.story.getAllMetadata()
                 call(string.Template(adapter.getConfig('pre_process_cmd')).substitute(metadata), shell=True)
 
-            output_filename = write_story(configuration, adapter, options.format, options.metaonly)
-            logger.debug("Successfully wrote '%s'"%output_filename)
+            output_filename = write_story(configuration, adapter, options.format,
+                                          metaonly=options.metaonly, nooutput=options.nooutput)
 
             if options.metaonly and not options.jsonmeta:
                 metadata = adapter.getStoryMetadataOnly().getAllMetadata()
@@ -559,6 +568,7 @@ def get_configuration(url,
     try:
         configuration.add_section('overrides')
     except configparser.DuplicateSectionError:
+        # generally already exists in defaults.ini
         pass
 
     if options.force:
