@@ -282,7 +282,6 @@ def get_valid_set_options():
                'replace_failed_smilies_with_alt_text':(base_xenforo_list,None,boollist),
                'use_threadmark_wordcounts':(base_xenforo_list,None,boollist),
                'always_include_first_post_chapters':(base_xenforo_list,None,boollist),
-               'fetch_last_page':(base_xenforo_list,None,boollist),
                'use_threadmarks_description':(base_xenforo2_list,None,boollist),
                'use_threadmarks_status':(base_xenforo2_list,None,boollist),
                'use_threadmarks_cover':(base_xenforo2_list,None,boollist),
@@ -499,7 +498,6 @@ def get_valid_keywords():
                  'use_threadmarks_status',
                  'use_threadmarks_cover',
                  'datethreadmark_format',
-                 'fetch_last_page',
                  'fix_pseudo_html',
                  'fix_excess_space',
                  'ignore_chapter_url_list',
@@ -1051,6 +1049,8 @@ class Configuration(configparser.SafeConfigParser):
         sleeps.  Passed into fetchs so it can be bypassed when
         cache hits.
         '''
+        url = quote_plus(ensure_binary(url),safe=';/?:@&=+$,%&#')
+
         if self.getConfig('force_https'): ## For developer testing only.
             url = url.replace("http:","https:")
         cachekey=self._get_cachekey(url, parameters, headers)
@@ -1114,7 +1114,7 @@ class Configuration(configparser.SafeConfigParser):
         cache hits.
         '''
 
-        url = quote_plus(ensure_binary(url),safe=';/?:@&=+$,%&')
+        url = quote_plus(ensure_binary(url),safe=';/?:@&=+$,%&#')
 
         if self.getConfig('force_https'): ## For developer testing only.
             url = url.replace("http:","https:")
