@@ -29,7 +29,8 @@ import sys
 import types
 
 __author__ = "Benjamin Peterson <benjamin@python.org>"
-__version__ = "1.11.0fff" # for version included in fanficfare
+__version__ = "1.12.0fff" # for version included in fanficfare
+
 
 # Useful for very coarse version differentiation.
 PY2 = sys.version_info[0] == 2
@@ -843,6 +844,8 @@ def add_metaclass(metaclass):
                 orig_vars.pop(slots_var)
         orig_vars.pop('__dict__', None)
         orig_vars.pop('__weakref__', None)
+        if hasattr(cls, '__qualname__'):
+            orig_vars['__qualname__'] = cls.__qualname__
         return metaclass(cls.__name__, cls.__bases__, orig_vars)
     return wrapper
 
